# GTAZ
Visual-based AI for real-time tasks in GTAV.

![](https://img.shields.io/pypi/v/gtaz?label=gtaz&color=blue&cacheSeconds=60)

## Thanks to

Lots of codes (especially the gamepad simulator ) are inspired by and inherited from:

- [shibeta/JNTMbot_python](https://github.com/shibeta/JNTMbot_python)

Without the original author's great work, this project would not be possible.

## Install package

```sh
pip install gtaz --upgrade
```

## Usage

TODO